//+------------------------------------------------------------------+
//|                                                     NoWickCandle |
//|                      Copyright 2023, YourNameHere               |
//|                                       https://www.example.com    |
//+------------------------------------------------------------------+
#property copyright "Copyright 2023, YourNameHere"
#property link      "https://www.example.com"
#property version   "1.00"
#property indicator_chart_window

// Input parameters
extern int WickPercentage = 10; // Percentage of the candle body compared to the whole candle

// Colors for drawing candles
color BullCandleColor = Lime;
color BearCandleColor = Red;

// Buffer to store indicator values
double noWickBuffer[];

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
{
    // Set up the buffer
    SetIndexStyle(0, DRAW_ARROW, EMPTY, 3, clrNONE); // Invisible arrow
    SetIndexArrow(0, SYMBOL_ARROWUP); // Up arrow
    SetIndexBuffer(0, noWickBuffer); // Assign the buffer
    SetIndexDrawBegin(0, 0); // Set the starting point for drawing arrows
    IndicatorSetInteger(INDICATOR_DIGITS, _Digits + 1); // To show arrows correctly on 5-digit brokers
    
    // Allow the indicator to display its values for the entire chart history
    IndicatorSetInteger(INDICATOR_DIGITS, _Digits + 1);
    SetIndexBuffer(0, noWickBuffer);
    SetIndexLabel(0, "NoWickCandle");
    SetIndexEmptyValue(0, 0.0);
    
    return (0);
}

//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
{
    int counted_bars = IndicatorCounted();
    int limit = Bars - counted_bars;
    int wickLength, bodyLength;
    
    for (int i = limit; i >= 0; i--)
    {
        wickLength = High[i] - Low[i] - MathAbs(Close[i] - Open[i]);
        bodyLength = MathAbs(Close[i] - Open[i]);
        
        // Check if there are no wicks on one side
        if (wickLength < bodyLength * WickPercentage / 100)
        {
            // Determine the candle direction
            if (Close[i] >= Open[i])
                noWickBuffer[i] = Low[i] - 5 * Point;
            else
                noWickBuffer[i] = High[i] + 5 * Point;
        }
        else
        {
            noWickBuffer[i] = EMPTY_VALUE; // No arrow
        }
    }

    return (0);
}
//+------------------------------------------------------------------+
